@@ -313,7 +313,8 @@ pub trait CheckoutContext:
 
 #[async_trait]
 pub trait CheckoutContextProvider {
-    async fn new_context<T: CheckoutContext>(&self) -> Result<T, CheckoutError>;
+    type Context: CheckoutContext;
+    async fn new_context(&self) -> Result<Self::Context, CheckoutError>;
 }
 
 #[derive(Debug, Serialize, Deserialize)]
