@@ -5,21 +5,22 @@ use crate::{
     CheckoutError,
 };
 use async_trait::async_trait;
+use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
 
-#[derive(Serialize, Deserialize)]
+#[derive(Serialize, Deserialize, JsonSchema)]
 pub enum FulfillmentType {
     Pickup,
     Shipping(ShippingQuote),
 }
 
-#[derive(Serialize, Deserialize)]
+#[derive(Serialize, Deserialize, JsonSchema)]
 pub enum FulfillmentTypeSelection {
     Pickup,
     Shipping(String),
 }
 
-#[derive(Clone, Serialize, Deserialize)]
+#[derive(Clone, Serialize, Deserialize, JsonSchema)]
 pub struct ShippingQuote {
     pub id: String,
     pub service: Service,
@@ -27,13 +28,13 @@ pub struct ShippingQuote {
     pub discount: Money,
 }
 
-#[derive(Clone, Serialize, Deserialize)]
+#[derive(Clone, Serialize, Deserialize, JsonSchema)]
 pub struct Courier {
     pub id: String,
     pub name: String,
 }
 
-#[derive(Clone, Serialize, Deserialize)]
+#[derive(Clone, Serialize, Deserialize, JsonSchema)]
 pub struct Service {
     pub id: String,
     pub courier: Courier,
